###DOmake.wind.page.plots - creates 24hr profile ps plot file of INS data
##
## smsmith Mar96 mlvl62 - based on DOmake.imet.page.plot
## Modif J.S.Charters Jun99 mlvl62 Change in ins_met
## Modif J.S.Charters Jan00 revelle, add units of ship speed
## Modif J.S.Charters Mar01 Revelle Major changes. 
##		1. make a weekly plot
##		2. filter the data a bit.
#
# Assumes environmental variables CRUISE, DIRUWDATA and BINDIR are set.

unset noclobber

if ($#argv < 1) then
   echo "usage: DOmake.tran_weekly_wind.page.plot   <date.ext>"
   echo " (produces profile ps file named metfile.<date.ext>.ps)"
   exit
endif

# Change these Lower/Upper ranges as necessary:

set WIND_SPD_RANGE = 15/40
set WIND_SPD_TIC = "a2g2f1:Wind Speed"

set WIND_DIR_RANGE = 0/360
set WIND_DIR_TIC = "a60g30f15:Wind Dir"

set SHIP_DIR_RANGE = 0/360
set SHIP_DIR_TIC = "a60g30f15:Ship Dir:"

set SHIP_SPD_RANGE = 0/360
set SHIP_SPD_TIC = "a2g2f1:Ship Speed(m/s):"


# Don't change these:
set HR_RANGE       = 0./7.
set HR_TIC       = "2g1::"

cd $DIRUWDATA/TRANS

set DATE = $1

#
# Get a list of last 7 days of data
set tem0 = $1
set IFN7 = `$BINDIR/trans_filename $tem0`cor
set  tem1 = `$BINDIR/yesterday $tem0`
set IFN6 = `$BINDIR/trans_filename $tem1`cor
set  tem2 = `$BINDIR/yesterday $tem1`
set IFN5 = `$BINDIR/trans_filename $tem2`cor
set  tem3 = `$BINDIR/yesterday $tem2`
set IFN4 = `$BINDIR/trans_filename $tem3`cor
set  tem4 = `$BINDIR/yesterday $tem3`
set IFN3 = `$BINDIR/trans_filename $tem4`cor
set  tem5 = `$BINDIR/yesterday $tem4`
set IFN2 = `$BINDIR/trans_filename $tem5`cor
set  tem6 = `$BINDIR/yesterday $tem5`
set IFN1 = `$BINDIR/trans_filename $tem6`cor

/bin/rm -f weekly.wind
touch weekly.wind
set file_cnt = 0
foreach i ( $IFN1 $IFN2 $IFN3 $IFN4 $IFN5 $IFN6 $IFN7 )
        echo Processing met file $i
        if ( -e $i.Z ) then
                zcat $i | $BINDIR/tran_truewind >> weekly.wind
                @ file_cnt++
        else
                if ( -e $i) then
                        @ file_cnt++
                        $BINDIR/tran_truewind < $i >> weekly.wind
		else
			echo "File does not exist $i"
                endif
        endif
end

# Don't change these:
set HR_RANGE       = 0./$file_cnt.       ; set HR_TIC       = "2g1::"
echo $HR_RANGE


if ( $file_cnt == 0) then
        echo No file found, exiting
        exit
endif

###################################################

set PAGE_SIZE = letter

set OFN = WEEKLY.WIND.$DATE.ps

if ("$PAGE_SIZE" == "letter") then
   set XLENGTH = 6.5
   set YLENGTH = 1.1
   set XOFF1 = 1.2 ; set YOFF1 =  8.5
   set XOFF2 = 0.0 ; set YOFF2 = -1.5
   set OPT    = " -P "
else if ("$PAGE_SIZE" == "E") then
   echo E-size not done yet...
   exit
else 
   echo Should not be here with PAGE_SIZE of $PAGE_SIZE...
   exit
endif

set TITLE1   = "$CRUISE Wind Data week ending $DATE"
set TITLE2   = ""

set SIZE     = "$XLENGTH"/"$YLENGTH"
set SIZE_REV = "$XLENGTH"/-"$YLENGTH"
set AXES     = WeSn
gmtset ANOT_FONT_SIZE 10p HEADER_FONT_SIZE 16p LABEL_FONT_SIZE 12p


###################### start the postscript file ############################
pwd | psxy -H1 >! $OFN -R0/1/0/1 -JX1/1 -X0 -Y0 -K `echo "$OPT"`

###################### start 1st panel ######################################
#
# Wind Speed relative

$BINDIR/trans_ins_data_weekly.awk field=2 scale=10 weekly.wind > 2col.raw
filter1d 2col.raw -Fm0.005 > 2col

set XOFF   = $XOFF1
set YOFF   = $YOFF1
set TITLE  = "$TITLE1"
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$WIND_SPD_TIC(Relative):"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
set SYMB   = x0.05

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M -S"$SYMB"

psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################


###################### start 2nd panel ######################################
# Wind direction relative

$BINDIR/trans_ins_data_weekly.awk field=3 scale=20 weekly.wind > 2col.raw
filter1d 2col.raw -Fm0.005 > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/"$WIND_DIR_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$WIND_DIR_TIC(Relative):"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

###################### start 3nd panel ######################################
#true speed
$BINDIR/trans_ins_data_weekly.awk field=4 scale=10 weekly.wind > 2col.raw
filter1d 2col.raw -Fm0.005 > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$WIND_SPD_TIC(True):"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

###################### start 4nd panel ######################################
# true direction

$BINDIR/trans_ins_data_weekly.awk field=5 scale=20 weekly.wind > 2col.raw
filter1d 2col.raw -Fm0.005 > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/"$WIND_DIR_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$WIND_DIR_TIC(True):"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#
###################### start 5nd panel ######################################
#ship speed
$BINDIR/trans_ins_data_weekly.awk field=6 scale=10 weekly.wind > 2col.raw
filter1d 2col.raw -Fm0.005 > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$SHIP_SPD_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

###################### start 6nd panel ######################################
#ship dir

$BINDIR/trans_ins_data_weekly.awk field=7 scale=20 weekly.wind > 2col.raw
filter1d 2col.raw -Fm0.005 > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/"$WIND_DIR_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$SHIP_DIR_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

### finish off the postscript file ##########################################
pwd | psxy -H1 >> $OFN -R -JX -O `echo "$OPT"`
#
# Print the file
#
lp $OFN

#
# Remove work files
#
/bin/rm -f weekly.wind range 2col 2col.raw
