/* program convert_fixed_table
 *
 * Program to convert fixed-format records into lon-lat-value data
 *
 * compile with: cc convert_fixed_table.c dansubs.o -lm -o convert_fixed_table
 *
 * Dan Scheirer, 27 October 1994
 *   2 May 1995 -- added option -2 for gna-cd earthquake data, and option -R
 *                 for output only from a region, -N for minimum magnit output
 *                 also option -3 for harvard cmt data and -4 for PDE.cat data
 *  24 Oct 1995 -- added option -5 for SIO uwmrg marine geophysical data
 *  21 Mar 1996 -- fixed option -5 for SIO uwmrg grav and mag anom.
 *
 */

#include <stdio.h>
#include <math.h>
#include <string.h>

#define TRUE 	1
#define FALSE 	0
#define MAXLINE	1000
#define MAXSTR	10
#define MS 	MAXSTR

int getline();
void decimal_cat();

main(argc,argv)
int argc;
char *argv[];

{
char *prog ;
char buff[MAXLINE], outbuff[MAXLINE], tmpbuff[MAXLINE] ;
char station_id[MAXLINE] ;
char latd_s[MAXLINE], lond_s[MAXLINE] ;
char latm_s[MAXLINE], lonm_s[MAXLINE] ;
char elev_ft_s[MAXLINE], obs_grav_s[MAXLINE] ;
char acc_code[MAXLINE],  free_air_anom_s[MAXLINE] ;
char bouguer_anom_simp_s[MAXLINE] ;
char terr_corr_inner_s[MAXLINE],  terr_corr_total_s[MAXLINE] ;
char bouguer_anom_267_s[MAXLINE], isostatic_anom_s[MAXLINE] ;
char source_id[MAXLINE] ;

int i, icount=0, iwritten=0, error=FALSE, verbose=FALSE;
int preserve_multisegment=FALSE, opt_sum;
int opt_1=FALSE, opt_2=FALSE, opt_3=FALSE ;
int opt_4=FALSE, opt_5=FALSE, opt_6=FALSE ;
int format ;

double min_x=-1.e16, max_x=1.e16;
double min_y=-1.e16, max_y=1.e16;

/* added with opt_1 */
double dlat, dlon, elev_m, obs_grav ;
double free_air_anom, bouguer_anom_simp ;
double terr_corr_inner, terr_corr_total ;
double bouguer_anom_267, isostatic_anom ;
double min_magnitude = -1000 ;
int specify_min_magnitude = FALSE ;

/* added with opt_2 */
char year_s[MS],  month_s[MS], day_s[MS],   hour_s[MS], min_s[MS]  ;
char sec_s[MS],   auth_s[MS],  dlat_s[MS],  dlon_s[MS], depth_s[MS] ;
char regno_s[MS], maxno_s[MS], mag_b_s[MS], mag_s_s[MS] ;
char mag_o_s[MS], src_o_s[MS], mag_1_s[MS], src_1_s[MS] ;
char mag_2_s[MS], src_2_s[MS], mag_3_s[MS], src_3_s[MS] ;
char mag_4_s[MS], src_4_s[MS] ;
int    year, month, day, hour, min, regno, maxno, jday ;
double sec, depth ;
double mag_b, mag_s, mag_o, mag_1, mag_2, mag_3, mag_4, mag_max ;
double day_dec, year_dec ;
long   unix_sec ;

/* added with opt_3 */
char eps_s[MS],  dt_s[MS], ahdur_s[MS], clat_s[MS], clon_s[MS] ;
char cdep_s[MS] ;
char str1_s[MS], dip1_s[MS], rak1_s[MS] ;
char str2_s[MS], dip2_s[MS], rak2_s[MS] ;
double dt, ahdur, clat, clon, cdep ;
int    str1, dip1, rak1, str2, dip2, rak2 ;
  
/* added with opt_4 */
char type_s[MS] ;
int output_yymmdd=FALSE, output_both_times=FALSE ;

/* added with opt_5 */
char lon_sign[1], lat_sign[1], yymmdd_s[7], hhmm_s[5] ;
int latd_i, lond_i, record_no ;
double latm, lonm, dhour ;
double course_deg, speed_kts, dist_nm, depth_1500m, depth_corrected ;
double mag_tot, mag_anom, grav_tot, grav_anom ;
double void_val = -999999. ;

if ((prog= strrchr(*argv, (int) '/')) != (char *) NULL) prog++;
else                                                    prog= *argv;

/* process the command line arguments */
for (i=1; i<argc; i++) {
   if (argv[i][0] == '#') break;  /* allow command-line comments */
   if (argv[i][0] == '-') {
      switch(argv[i][1]) {
	case '1':
		opt_1=TRUE;
		break;
	case '2':
		opt_2=TRUE;
		break;
	case '3':
		opt_3=TRUE;
		break;
	case '4':
		opt_4=TRUE;
		break;
	case '5':
		opt_5=TRUE;
		break;
	case '6':
		opt_6=TRUE;
		break;
	case 'M':
		preserve_multisegment = TRUE;
		break;
	case 'R':
		sscanf (&argv[i][2], "%lf/%lf/%lf/%lf",
                	&min_x, &max_x, &min_y, &max_y);
		break;
	case 'N':
		specify_min_magnitude = TRUE ;
		min_magnitude = atof(&argv[i][2]);
		break;
	case 'Y':
		output_yymmdd = TRUE;
		break;
	case 'B':
		output_both_times = TRUE;
		break;
	case 'Q':
		error = TRUE;
		break;
	case 'V':
		verbose = TRUE;
		break;
	default :
		error = TRUE;
		fprintf(stderr,"%s: UNKNOWN OPTION: %c\n", prog, argv[i][1]);
		break;
	} /* end switch */
      } /* end if */
   else
      error = TRUE;
   } /* end for -- running through command line arguments */


opt_sum = opt_1 + opt_2 + opt_3 + opt_4 + opt_5 + opt_6 ;
 
if ( opt_sum == 0) 
   {
   fprintf(stderr,"%s: one of -1, -2, -3, ... must be specified.\n", prog);
   error = TRUE;
   }

if ( opt_sum > 1) 
   {
   fprintf(stderr,"%s: only one of -1, -2, -3, ... can be specified.\n", prog);
   error = TRUE;
   }

if (max_x <= min_x || min_y >= max_y) 
   {
   fprintf(stderr,"%s: CHECK X-Y BOUNDS!\n", prog);
   error = TRUE;
   }


if (specify_min_magnitude == TRUE && (opt_2+opt_3+opt_4) != 1) 
   {
   fprintf(stderr,"%s: must specify option 2, 3, or 4 for min_magnitude -N!\n", prog);
   error = TRUE;
   }

if (output_yymmdd == TRUE && opt_4 == FALSE) 
   {
   fprintf(stderr,"%s: can only output_yymmdd, -Y, with option 4!\n", prog);
   error = TRUE;
   }

if (output_both_times == TRUE && opt_4 == FALSE) 
   {
   fprintf(stderr,"%s: can only output_both_times, -B, with option 4!\n", prog);
   error = TRUE;
   }

if (output_both_times == TRUE && output_yymmdd == TRUE) 
   {
   fprintf(stderr,"%s: either output_both_times, -B, *OR* output_yymmdd, -Y !\n", prog);
   error = TRUE;
   }

if(isatty(fileno(stdin))) /* don't take terminal input */
   {
   fprintf(stderr,"%s: DOESN'T ACCEPT INPUT FROM TERMINAL.\n", prog);
   error = TRUE; 
   }

if (error == TRUE) fprintf(stderr,"");

if (error) {
fprintf(stderr,"\nusage: convert_fixed_table  < > -1 -2 -3 -4 -5 -6 -M -R -N -Q -Y -B -V\n\n", prog);
fprintf(stderr,"  -1 : input is nevada station data        [OFF]\n");
fprintf(stderr,"  -2 : input is gna-cd earthquake data     [OFF]\n");
fprintf(stderr,"  -3 : input is 1-line output from selcmt  [OFF]\n");
fprintf(stderr,"  -4 : input is from Matt's PDE catalogue  [OFF]\n");
fprintf(stderr,"  -5 : input is SIO uwmerg ASCII listing   [OFF]\n");
fprintf(stderr,"  -6 : not supported yet                   [OFF]\n");
fprintf(stderr,"  -M : preserve Multisegment divider lines (>) [OFF]\n");
fprintf(stderr,"  -R : only output points in the given area \n");
fprintf(stderr,"       xmin/xmax/ymin/ymax                 [huge range]\n");
fprintf(stderr,"  -N : miNimum magnitude for output quake  [OFF]\n");
fprintf(stderr,"  -Y : opt. 4: output date as YYMMDD       [decimal years]\n");
fprintf(stderr,"  -B : opt. 4: output date Both as YYMMDD and dec yr [decimal years]\n");
fprintf(stderr,"  -Q : Query program for usage\n");
fprintf(stderr,"  -V : Verbose operation                   [OFF]\n\n");
fprintf(stderr,"Converts fixed format records to lon-lat-values.\n\n");
exit(-1);
}


while (getline(buff,MAXLINE,stdin) > 0)
   {
   if (preserve_multisegment==TRUE && buff[0]=='>')
	{
	fprintf(stdout,"%s",buff);
	continue;
	}
   icount++;

   if ( opt_1 == TRUE )
	{
	sscanf(buff, "%8s", station_id ) ;

	decimal_cat(latd_s, buff,  9, 2, 0) ;
	decimal_cat(latm_s, buff, 11, 2, 2) ;
	decimal_cat(lond_s, buff, 15, 4, 0) ;
	decimal_cat(lonm_s, buff, 19, 2, 2) ;
	dlat = atof(latd_s) + atof(latm_s) / 60. ;
	dlon = atof(lond_s) - atof(lonm_s) / 60. ;

	if (dlon < min_x || dlon > max_x) continue ;
	if (dlat < min_y || dlat > max_y) continue ;

	decimal_cat(elev_ft_s, buff, 23, 5, 1) ;
	elev_m = atof(elev_ft_s) / 3.28 ;

	decimal_cat(obs_grav_s, buff, 29, 5, 2) ;
	obs_grav = atof(obs_grav_s) + 900000. ;

	strncpy(acc_code, buff+36, 4);
	acc_code[4] = '\0' ;

	decimal_cat(free_air_anom_s, buff, 40, 4, 2);
	free_air_anom = atof(free_air_anom_s);

	decimal_cat(bouguer_anom_simp_s, buff, 44, 4, 2);
	bouguer_anom_simp = atof(bouguer_anom_simp_s);

	decimal_cat(terr_corr_inner_s, buff, 52, 3, 2);
	terr_corr_inner = atof(terr_corr_inner_s);

	decimal_cat(terr_corr_total_s, buff, 57, 3, 2);
	terr_corr_total = atof(terr_corr_total_s);

	decimal_cat(bouguer_anom_267_s, buff, 63, 4, 2);
	bouguer_anom_267 = atof(bouguer_anom_267_s);

	decimal_cat(isostatic_anom_s, buff, 69, 4, 2);
	isostatic_anom = atof(isostatic_anom_s);

	strncpy(source_id, buff+75, 5);
	source_id[5] = '\0' ;


	sprintf(outbuff,"%lf %lf %8s %lf %lf %lf %lf\n", 
		dlon, dlat, station_id, elev_m, obs_grav,
		free_air_anom, bouguer_anom_267);

	} /* end if -- opt_1 == TRUE */


   if ( opt_2 == TRUE )
	{

	decimal_cat(year_s,  buff,  5, 4, 0) ; year  = atoi(year_s) ;
	decimal_cat(month_s, buff,  9, 2, 0) ; month = atoi(month_s) ;
	decimal_cat(day_s,   buff, 11, 2, 0) ; day   = atoi(day_s) ;
	decimal_cat(hour_s,  buff, 13, 2, 0) ; hour  = atoi(hour_s) ;
	decimal_cat(min_s,   buff, 15, 2, 0) ; min   = atoi(min_s) ;
	decimal_cat(sec_s,   buff, 17, 5, 0) ; sec   = atof(sec_s) ;
	decimal_cat(auth_s,  buff, 22, 3, 0) ;
	decimal_cat(dlat_s,  buff, 25, 6, 3) ; dlat  = atof(dlat_s) ;
	decimal_cat(dlon_s,  buff, 31, 8, 3) ; dlon  = atof(dlon_s) ;
	decimal_cat(depth_s, buff, 39, 5, 1) ; depth = atof(depth_s) ;
	decimal_cat(regno_s, buff, 44, 3, 0) ; regno = atoi(regno_s) ;
	decimal_cat(maxno_s, buff, 47, 3, 0) ; maxno = atoi(maxno_s) ;

	decimal_cat(mag_b_s, buff, 50, 3, 1) ; mag_b = atof(mag_b_s) ;
	decimal_cat(mag_s_s, buff, 53, 3, 1) ; mag_s = atof(mag_s_s) ;
	decimal_cat(mag_o_s, buff, 56, 4, 2) ; mag_o = atof(mag_o_s) ;
	decimal_cat(src_o_s, buff, 60, 7, 0) ;
	decimal_cat(mag_1_s, buff, 67, 4, 2) ; mag_1 = atof(mag_1_s) ;
	decimal_cat(src_1_s, buff, 71, 7, 0) ;
	decimal_cat(mag_2_s, buff, 78, 4, 2) ; mag_2 = atof(mag_2_s) ;
	decimal_cat(src_2_s, buff, 82, 7, 0) ;
	decimal_cat(mag_3_s, buff, 89, 4, 2) ; mag_3 = atof(mag_3_s) ;
	decimal_cat(src_3_s, buff, 93, 7, 0) ;
	decimal_cat(mag_4_s, buff,100, 4, 2) ; mag_4 = atof(mag_4_s) ;
	decimal_cat(src_4_s, buff,111, 7, 0) ;

	if (dlon < min_x || dlon > max_x) continue ;
	if (dlat < min_y || dlat > max_y) continue ;

	mag_max = mag_b ;
	if (mag_s > mag_max) mag_max = mag_s ;
	if (mag_o > mag_max) mag_max = mag_o ;
	if (mag_1 > mag_max) mag_max = mag_1 ;
	if (mag_2 > mag_max) mag_max = mag_2 ;
	if (mag_3 > mag_max) mag_max = mag_3 ;
	if (mag_4 > mag_max) mag_max = mag_4 ;
	if (specify_min_magnitude && mag_max < min_magnitude) continue ;

	unix_sec = caluxs(year,jday,month,day,hour,min,sec);
		
	day_dec  = (double)jday + (double)hour/24. + 
	           (double)min/24./60. + (double)sec/24./60./60. ;
	year_dec = (double) year + day_dec / 366.; /* bad for leap yr */

	sprintf(outbuff,"%.3lf %.3lf %lf %5.1lf %4.2lf \n",
                        dlon, dlat, year_dec, depth, mag_max);

	} /* end if -- opt_2 == TRUE */



   if ( opt_3 == TRUE )
	{

	decimal_cat(year_s,  buff,  0, 2, 0) ; year  = atoi(year_s) ;
	decimal_cat(month_s, buff,  2, 2, 0) ; month = atoi(month_s) ;
	decimal_cat(day_s,   buff,  4, 2, 0) ; day   = atoi(day_s) ;
	decimal_cat(hour_s,  buff,  6, 3, 0) ; hour  = atoi(hour_s) ;
	decimal_cat(min_s,   buff,  9, 2, 0) ; min   = atoi(min_s) ;
	decimal_cat(sec_s,   buff, 11, 4, 1) ; sec   = atof(sec_s) ;
	decimal_cat(dlat_s,  buff, 15, 8, 2) ; dlat  = atof(dlat_s) ;
	decimal_cat(dlon_s,  buff, 23, 8, 2) ; dlon  = atof(dlon_s) ;
	decimal_cat(depth_s, buff, 31, 6, 1) ; depth = atof(depth_s) ;

	decimal_cat(mag_s_s, buff, 37, 3, 1) ; mag_s = atof(mag_s_s) ;
	decimal_cat(mag_b_s, buff, 40, 3, 1) ; mag_b = atof(mag_b_s) ;
	decimal_cat(eps_s,   buff, 43, 3, 0) ; 
	decimal_cat(dt_s,    buff, 46, 4, 1) ; dt    = atof(dt_s) ;
	decimal_cat(ahdur_s, buff, 50, 4, 1) ; ahdur = atof(ahdur_s) ;
	decimal_cat(clat_s,  buff, 54, 8, 2) ; clat  = atof(clat_s) ;
	decimal_cat(clon_s,  buff, 62, 8, 2) ; clon  = atof(clon_s) ;
	decimal_cat(cdep_s,  buff, 70, 6, 1) ; cdep  = atof(cdep_s) ;
	decimal_cat(str1_s,  buff,150, 4, 0) ; str1  = atoi(str1_s) ;
	decimal_cat(dip1_s,  buff,154, 4, 0) ; dip1  = atoi(dip1_s) ;
	decimal_cat(rak1_s,  buff,158, 5, 0) ; rak1  = atoi(rak1_s) ;
	decimal_cat(str2_s,  buff,163, 4, 0) ; str2  = atoi(str2_s) ;
	decimal_cat(dip2_s,  buff,167, 4, 0) ; dip2  = atoi(dip2_s) ;
	decimal_cat(rak2_s,  buff,171, 5, 0) ; rak2  = atoi(rak2_s) ;

	dlon = clon ;
	dlat = clat ;
	depth = cdep ;

	if (dlon < min_x || dlon > max_x) continue ;
	if (dlat < min_y || dlat > max_y) continue ;

	if (specify_min_magnitude && mag_b < min_magnitude) continue ;

	unix_sec = caluxs(year,jday,month,day,hour,min,sec);
		
	day_dec  = (double)jday + (double)hour/24. + 
	           (double)min/24./60. + (double)sec/24./60./60. ;
		year_dec = (double) year + day_dec / 366.; /* bad for leap yr */

	/* outputting str1, dip1, rak1 gives same psvelomeca results as
	outputting str2, dip2, rak2 */
	sprintf(outbuff,
	   "%.3lf %.3lf %02d/%02d/%02d %5.1lf %3.1lf %4d %4d %4d \n",
	   dlon, dlat, year, month, day, depth, mag_b, str1, dip1,rak1);

	} /* end if -- opt_3 == TRUE */



   if ( opt_4 == TRUE )
	{
	decimal_cat(year_s,  buff,  0, 2, 0) ; year  = atoi(year_s) ;
	decimal_cat(month_s, buff,  2, 2, 0) ; month = atoi(month_s) ;
	decimal_cat(day_s,   buff,  4, 2, 0) ; day   = atoi(day_s) ;
	decimal_cat(hour_s,  buff,  9, 2, 0) ; hour  = atoi(hour_s) ;
	decimal_cat(min_s,   buff, 11, 2, 0) ; min   = atoi(min_s) ;
	decimal_cat(sec_s,   buff, 13, 5, 2) ; sec   = atof(sec_s) ;
	decimal_cat(dlat_s,  buff, 18, 9, 3) ; dlat  = atof(dlat_s) ;
	decimal_cat(dlon_s,  buff, 27,11, 3) ; dlon  = atof(dlon_s) ;
	decimal_cat(depth_s, buff, 38, 7, 0) ; depth = atof(depth_s) ;

	decimal_cat(mag_b_s, buff, 45, 6, 1) ; mag_b = atof(mag_b_s) ;
	decimal_cat(mag_o_s, buff, 51, 6, 1) ; mag_o = atof(mag_o_s) ;
	decimal_cat(type_s,  buff, 57, 8, 0) ; 

	if (dlon < min_x || dlon > max_x) continue ;
	if (dlat < min_y || dlat > max_y) continue ;

	unix_sec = caluxs(year,jday,month,day,hour,min,sec);

	mag_max = mag_b ;
	if (mag_o > mag_max) mag_max = mag_o ;
	if (specify_min_magnitude && mag_max < min_magnitude) continue ;

	day_dec  = (double)jday + (double)hour/24. + 
	           (double)min/24./60. + (double)sec/24./60./60. ;
	year_dec = (double) year + day_dec / 366.; /* bad for leap yr */

	if (output_yymmdd == TRUE)
	   {
	   sprintf(outbuff,"%.3lf %.3lf %02d%02d%02d %02d%02d%05.2lf %5.1lf %4.2lf\n",
                        dlon, dlat, (int)year, (int)month, (int)day,
			(int)hour, (int)min, sec, depth, mag_max);
	   }
	else if (output_both_times == TRUE)
	   {
	   sprintf(outbuff,"%.3lf %.3lf %02d%02d%02d %02d%02d%05.2lf 19%lf %5.1lf %4.2lf\n",
                 dlon, dlat, (int)year, (int)month, (int)day,
		 (int)hour, (int)min, sec, year_dec, depth, mag_max);
	   }
	else
	   {
	   sprintf(outbuff,"%.3lf %.3lf 19%lf %5.1lf %4.2lf\n",
                        dlon, dlat, year_dec, depth, mag_max);
	   }

	} /* end if -- opt_4 == TRUE */



   if ( opt_5 == TRUE )
	{

        if (buff[0] == '#') continue ;
/*	sscanf(buff, "%6s %4s %d %lf %1s %d %lf %1s %lf %lf", 
		yymmdd_s, hhmm_s, &latd_i, &latm, lat_sign, 
		&lond_i, &lonm, lon_sign, &course_deg, &speed_kts);
	sscanf(yymmdd_s, "%2d%2d%2d", &year, &month, &day);
	sscanf(hhmm_s,   "%2d%2d",    &hour, &min);
	sscanf(buff, "%2d%2d%2d %2d%2d    %2d %7.4lf %1s  %2d %7.4lf %1s   %5.1lf   %4.1lf", 
		&year, &month, &day, &hour, &min, &latd_i, &latm, lat_sign, 
		&lond_i, &lonm, lon_sign, &course_deg, &speed_kts);
*/
	tmpbuff[0] = '\0' ;
	year     = atoi ( strncat(tmpbuff, buff+0,  2) ) ; tmpbuff[0] = '\0' ;
	month    = atoi ( strncat(tmpbuff, buff+2,  2) ) ; tmpbuff[0] = '\0' ;
	day      = atoi ( strncat(tmpbuff, buff+4,  2) ) ; tmpbuff[0] = '\0' ;
	hour     = atoi ( strncat(tmpbuff, buff+7,  2) ) ; tmpbuff[0] = '\0' ;
	min      = atoi ( strncat(tmpbuff, buff+9,  2) ) ; tmpbuff[0] = '\0' ;
	latd_i   = atoi ( strncat(tmpbuff, buff+15, 2) ) ; tmpbuff[0] = '\0' ;
	latm     = atof ( strncat(tmpbuff, buff+18, 7) ) ; tmpbuff[0] = '\0' ;
	strncpy(lat_sign, buff+26, 1) ;
	lond_i   = atoi ( strncat(tmpbuff, buff+29, 3) ) ;  tmpbuff[0] = '\0' ;
	lonm     = atof ( strncat(tmpbuff, buff+33, 7) ) ;  tmpbuff[0] = '\0' ;
	strncpy(lon_sign, buff+41, 1) ;
	course_deg = atof ( strncat(tmpbuff, buff+44, 5) ) ; tmpbuff[0] = '\0' ;
	speed_kts  = atof ( strncat(tmpbuff, buff+52, 4) ) ; tmpbuff[0] = '\0' ;
	dist_nm    = atof ( strncat(tmpbuff, buff+58, 7) ) ; tmpbuff[0] = '\0' ;
	depth_1500m     = atof ( strncat(tmpbuff, buff+68, 5) ) ; tmpbuff[0] = '\0' ;
	depth_corrected = atof ( strncat(tmpbuff, buff+76, 5) ) ; tmpbuff[0] = '\0' ;
	mag_tot   = atof ( strncat(tmpbuff, buff+84, 7) )  ; tmpbuff[0] = '\0' ;
	mag_anom  = atof ( strncat(tmpbuff, buff+93, 7) )  ; tmpbuff[0] = '\0' ;
	grav_tot  = atof ( strncat(tmpbuff, buff+103, 9) ) ; tmpbuff[0] = '\0' ;
	grav_anom = atof ( strncat(tmpbuff, buff+114, 7) ) ; tmpbuff[0] = '\0' ;
	record_no = atoi ( strncat(tmpbuff, buff+122, 6) ) ; tmpbuff[0] = '\0' ;

	dlat = (double) latd_i + latm / 60. ;
	if (lat_sign[0] == 'S') dlat *= -1. ;
	dlon = (double) lond_i + lonm / 60. ;
	if (lon_sign[0] == 'W') dlon *= -1. ;
	dhour = (double)hour + (double)min / 60. ;

	sec = 0.0 ;
	unix_sec = caluxs(year,jday,month,day,hour,min,sec);

/**
	fprintf(stderr,"buff is: %s", buff) ;
	fprintf(stderr,"year, month, day, hour, min are: %d %d %d %d %d\n", year, month, day, hour, min) ;
	fprintf(stderr,"dlat, dlon, course_deg, speed_kts: %lf %lf %lf %lf\n", dlat, dlon, course_deg, speed_kts) ;
	fprintf(stderr,"dist_nm, depth_1500m, depth_corrected, record_no: %lf %lf %lf %d\n", dist_nm, depth_1500m, depth_corrected, record_no) ;
	fprintf(stderr,"mag_tot, mag_anom, grav_tot, grav_anom: %lf %lf %lf %lf\n", mag_tot, mag_anom, grav_tot, grav_anom) ;
**/

	if (course_deg == 0. && speed_kts == 0.) 
	   {
	   course_deg = void_val ;
	   speed_kts  = void_val ;
	   }
	if (depth_1500m     == 0.) depth_1500m   = void_val ;
	if (depth_corrected == 0.) depth_corrected  = void_val ;
	if (mag_tot == 0.)   mag_tot   = void_val ;
	if (mag_anom == 0.)  mag_anom  = void_val ;
	if (grav_tot == 0.)  grav_tot  = void_val ;
	if (grav_anom == 0.) grav_anom = void_val ;

	sprintf(outbuff,"%02d %02d %02d %02d %02d %03d %lf %lf %lf %lf %lf %lf %lf %lf %lf %lf %lf %lf %d\n",
	   year, month, day, hour, min, jday, dhour, dlon, dlat, course_deg,
	   speed_kts, dist_nm, depth_1500m, depth_corrected, mag_tot, mag_anom,
	   grav_tot, grav_anom, record_no);

	} /* end if -- opt_5 == TRUE */



   if ( opt_6 == TRUE )
	{

	fprintf(stderr,"%s: opt_6 not supported yet!\n", prog);
	} /* end if -- opt_6 == TRUE */



   fprintf(stdout,"%s",outbuff);
   iwritten++ ;

   }  /* while -- end of data */

if (verbose) 
    {
    fprintf(stderr, "%s: %d records considered.\n", prog, icount);
    fprintf(stderr, "%s: %d records written.\n",    prog, iwritten);
    }

exit (0);

} /* end of main() */

